@@ -1,6 +1,6 @@
 /* ncdc - NCurses Direct Connect client
 
-  Copyright (c) Yoran Heling
+  Copyright (c) Yorhel
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -197,6 +197,10 @@ void ncdc_quit(void) {
 }
 
 
+#ifdef USE_GEOIP
+#include <maxminddb.h>
+#endif
+
 char *ncdc_version(void) {
   static GString *ver = NULL;
   static char *msg =
@@ -206,6 +210,16 @@ char *ncdc_version(void) {
      "yes (%s)\n"
 #else
      "no\n"
+#endif
+    "GeoIP support: "
+#if defined(USE_GEOIP) && defined(USE_LIBLOC)
+    "yes (libmaxminddb & libloc)\n"
+#elif defined(USE_GEOIP)
+    "yes (libmaxminddb)\n"
+#elif defined(USE_LIBLOC)
+    "yes (libloc)\n"
+#else
+    "no\n"
 #endif
     "Libraries:\n"
     "  GLib %d.%d.%d (%d.%d.%d)\n"
@@ -213,6 +227,9 @@ char *ncdc_version(void) {
     "  SQLite %s (%s)"
 #ifdef NCURSES_VERSION
     "\n  ncurses %s"
+#endif
+#ifdef USE_GEOIP
+    "\n  libmaxminddb %s"
 #endif
   ;
   if(ver)
@@ -230,6 +247,9 @@ char *ncdc_version(void) {
     SQLITE_VERSION, sqlite3_libversion()
 #ifdef NCURSES_VERSION
     , NCURSES_VERSION
+#endif
+#ifdef USE_GEOIP
+    , MMDB_lib_version()
 #endif
   );
   return ver->str;
@@ -343,6 +363,7 @@ static gboolean sighandle_sourcefunc(gpointer dat) {
   if(main_sig_log) {
     logfile_global_reopen();
     geoip_reinit();
+    loc_reinit();
     main_sig_log = FALSE;
   }
   return TRUE;
@@ -431,6 +452,7 @@ int main(int argc, char **argv) {
   ui_cmdhist_init("history");
   ui_init(bracketed_paste);
   geoip_reinit();
+  loc_reinit();
 
   // setup SIGWINCH
   struct sigaction act;
